@@ -1,6 +1,12 @@
 import editdistance  # type: ignore
 
-from librelingo_utils import get_dumb_opaque_id, audio_id, clean_word, iterate_phrases
+from librelingo_utils import (
+    get_dumb_opaque_id,
+    audio_id,
+    remove_control_characters_for_display,
+    clean_word,
+    iterate_phrases,
+)
 from .dictionary import _define_words_in_sentence
 
 
@@ -11,9 +17,16 @@ def get_listening_challenge(source, course):
     return [
         {
             "type": "listeningExercise",
-            "answer": source.in_target_language[0],
-            "meaning": source.in_source_language[0],
-            "audio": audio_id(course.target_language, source.in_target_language[0]),
+            "answer": remove_control_characters_for_display(
+                source.in_target_language[0]
+            ),
+            "meaning": remove_control_characters_for_display(
+                source.in_source_language[0]
+            ),
+            "audio": audio_id(
+                course.target_language,
+                remove_control_characters_for_display(source.in_target_language[0]),
+            ),
             "id": get_dumb_opaque_id("Word", source, "listeningExercise"),
             "priority": 1,
             "group": get_dumb_opaque_id("Group", source),
@@ -28,7 +41,10 @@ def get_short_input_challenge(source, course):
             "pictures": [pic + ".jpg" for pic in source.pictures]
             if source.pictures
             else None,
-            "formInTargetLanguage": source.in_target_language,
+            "formInTargetLanguage": [
+                remove_control_characters_for_display(t)
+                for t in source.in_target_language
+            ],
             "phrase": _define_words_in_sentence(
                 course, source.in_source_language[0], reverse=False
             ),
@@ -46,8 +62,12 @@ def get_cards_challenge(word, _):
             "pictures": [pic + ".jpg" for pic in word.pictures]
             if word.pictures
             else None,
-            "formInTargetLanguage": word.in_target_language[0],
-            "meaningInSourceLanguage": word.in_source_language[0],
+            "formInTargetLanguage": remove_control_characters_for_display(
+                word.in_target_language[0]
+            ),
+            "meaningInSourceLanguage": remove_control_characters_for_display(
+                word.in_source_language[0]
+            ),
             "id": get_dumb_opaque_id("Word", word, "cards"),
             "priority": 0,
             "group": get_dumb_opaque_id("Group", word),
@@ -59,8 +79,12 @@ def get_options_challenge(phrase, _):
     return [
         {
             "type": "options",
-            "formInTargetLanguage": phrase.in_target_language[0],
-            "meaningInSourceLanguage": phrase.in_source_language[0],
+            "formInTargetLanguage": remove_control_characters_for_display(
+                phrase.in_target_language[0]
+            ),
+            "meaningInSourceLanguage": remove_control_characters_for_display(
+                phrase.in_source_language[0]
+            ),
             "id": get_dumb_opaque_id("Options", phrase, "options"),
             "priority": 0,
             "group": get_dumb_opaque_id("Group", phrase),
@@ -137,7 +161,9 @@ def create_chips_challenge_generator(reverse):
                 ),
                 "chips": get_chips_from_phrase(get_input_texts, phrase, course),
                 "solutions": get_solutions_from_phrase(get_input_texts, phrase),
-                "formattedSolution": get_input_text(phrase),
+                "formattedSolution": remove_control_characters_for_display(
+                    get_input_text(phrase)
+                ),
                 "id": get_dumb_opaque_id(
                     "Chips", phrase, "reverse chips" if reverse else "chips"
                 ),
