@@ -1,13 +1,16 @@
 from pathlib import Path
-import click
+import click  # type: ignore
 import collections
 from librelingo_yaml_loader import load_course
 from librelingo_json_export.export import export_course
 
 
-Settings = collections.namedtuple("Settings", [
-    "dry_run",
-])
+Settings = collections.namedtuple(
+    "Settings",
+    [
+        "dry_run",
+    ],
+)
 
 DEFAULT_SETTINGS = Settings(
     dry_run=False,
@@ -20,12 +23,12 @@ def ensure_output_directory(output_path, settings):
 
 
 @click.command()
-@click.argument('input_path')
-@click.argument('output_path')
-@click.option('--dry-run/--no-dry-run', default=DEFAULT_SETTINGS.dry_run)
+@click.argument("input_path")
+@click.argument("output_path")
+@click.option("--dry-run/--no-dry-run", default=DEFAULT_SETTINGS.dry_run)
 def _command(input_path, output_path, dry_run):
     """
-        Convert a YAML course into JSON files to be consumed by the web app.
+    Convert a YAML course into JSON files to be consumed by the web app.
     """
     settings = Settings(
         dry_run=dry_run,
@@ -35,5 +38,5 @@ def _command(input_path, output_path, dry_run):
     export_course(output_path, course, settings)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     _command()
